@@ -1,6 +1,9 @@
+# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
+
 from dataclasses import dataclass
 from datetime import datetime, timedelta
-from enum import auto, Enum, IntEnum
+from enum import Enum, IntEnum, auto
 from typing import ClassVar, FrozenSet, List, Optional
 
 from .group import AndGroup, Group, GroupID
@@ -129,3 +132,10 @@ class Program:
             return None
 
         return aux(self.root_group)
+
+    def show(self):
+        """Print content of the Program.
+        """
+        print(f'Program: {self.id}')
+        # Print the group and atom information.
+        self.root_group.show(1)
